summaryrefslogtreecommitdiff
path: root/tools/lvconvert.c
diff options
context:
space:
mode:
authorDavid Teigland <teigland@redhat.com>2022-09-09 15:16:56 -0500
committerDavid Teigland <teigland@redhat.com>2022-09-09 15:50:00 -0500
commitb869a6ff7a3d254a56ad78444e7d7f8af93d6844 (patch)
tree3015c69054e85dbe924e2d5eff95455f4cc0832e /tools/lvconvert.c
parent6b05d6bd833c463b9a2074b2aa2bdaa531e7ab01 (diff)
downloadlvm2-b869a6ff7a3d254a56ad78444e7d7f8af93d6844.tar.gz
fix fs block size detection
blkid_get_tag_value() is not a reliable way to query the fs BLOCK_SIZE, so use the "probe" functions instead.
Diffstat (limited to 'tools/lvconvert.c')
-rw-r--r--tools/lvconvert.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/lvconvert.c b/tools/lvconvert.c
index 6e5d748cc..8888cac28 100644
--- a/tools/lvconvert.c
+++ b/tools/lvconvert.c
@@ -5996,7 +5996,7 @@ static int _set_writecache_block_size(struct cmd_context *cmd,
}
/*
* get_fs_block_size() returns the libblkid BLOCK_SIZE value,
* where libblkid has fs-specific code to set BLOCK_SIZE to the
* value we need here.
*
@@ -6008,7 +6008,7 @@ static int _set_writecache_block_size(struct cmd_context *cmd,
*
* With 512 LBS and 4K PBS, mkfs.xfs will use xfs sector size 4K.
*/
- rv = get_fs_block_size(pathname, &fs_block_size);
+ rv = fs_block_size_and_type(pathname, &fs_block_size, NULL, NULL);
skip_fs:
if (!rv || !fs_block_size) {
if (block_size_setting)
@@ -5996,7 +5996,7 @@ static int _set_writecache_block_size(struct cmd_context *cmd,
}
/*
- * get_fs_block_size() returns the libblkid BLOCK_SIZE value,
+ * fs_block_size_and_type() returns the libblkid BLOCK_SIZE value,
* where libblkid has fs-specific code to set BLOCK_SIZE to the
* value we need here.